#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vault
version:              0.3.1.6
visibility:           public
id:                   vault-0.3.1.6-1IN35hK8Ruj7GnQhH5nqOp
key:                  vault-0.3.1.6-1IN35hK8Ruj7GnQhH5nqOp
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2026
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  9750747fa04a7dfc1f0494f08cd364f8
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vault-0.3.1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vault-0.3.1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vault-0.3.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.6-1IN35hK8Ruj7GnQhH5nqOp
depends:
    base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-8qGpYVybfmaKH8giGSMaAG
    unordered-containers-0.2.20.1-9qHVoc2smYt9flJ6feRxGY

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

